#!/usr/bin/env python3

"""
An exception class inspired by the tidyverse style guide.
"""

from .exc import Error

__version__ = '0.2.0'

